aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-iax2.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-iax2.c')
-rw-r--r--epan/dissectors/packet-iax2.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/epan/dissectors/packet-iax2.c b/epan/dissectors/packet-iax2.c
index 266e016d07..023f18ac64 100644
--- a/epan/dissectors/packet-iax2.c
+++ b/epan/dissectors/packet-iax2.c
@@ -10,8 +10,8 @@
*
* $Id$
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs
*
* This program is free software; you can redistribute it and/or modify it
@@ -57,10 +57,10 @@
/* #define DEBUG_HASHING */
/* #define DEBUG_DESEGMENT */
/* Ethereal ID of the IAX2 protocol */
static int proto_iax2 = -1;
/* The following hf_* variables are used to hold the ethereal IDs of
* our header fields; they are filled out when we call
* proto_register_field_array() in proto_register_iax2()
*/
@@ -1980,7 +1980,7 @@ proto_register_iax2 (void)
{&hf_iax2_callno,
{"Call identifier", "iax2.call", FT_UINT32, BASE_DEC, NULL, 0,
- "This is the identifier Ethereal assigns to identify this call. It does "
+ "This is the identifier Wireshark assigns to identify this call. It does "
"not correspond to any real field in the protocol", HFILL }},
{&hf_iax2_scallno,
@@ -10,8 +10,8 @@
* $Id$
*
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
* Copyright 1998 Gerald Combs
*
@@ -57,10 +57,10 @@
/* #define DEBUG_HASHING */
/* #define DEBUG_DESEGMENT */
-/* Ethereal ID of the IAX2 protocol */
+/* Wireshark ID of the IAX2 protocol */
static int proto_iax2 = -1;
@@ -57,10 +57,10 @@
static int proto_iax2 = -1;
-/* The following hf_* variables are used to hold the ethereal IDs of
+/* The following hf_* variables are used to hold the wireshark IDs of
* our header fields; they are filled out when we call
* proto_register_field_array() in proto_register_iax2()